/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.lookup;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import javax.faces.el.ValueBinding;
import javax.faces.model.SelectItem;

import junit.framework.Test;
import junit.framework.TestSuite;

import org.apache.shale.test.base.AbstractViewControllerTestCase;
import org.apache.shale.usecases.view.Domains;

public class ListLocalesTestCase extends AbstractViewControllerTestCase {

	
    // Construct a new instance of this test case.
    public ListLocalesTestCase(String name) {
        super(name);
    }

	
    // Return the tests included in this test case.
    public static Test suite() {

        return (new TestSuite(ListLocalesTestCase.class));

    }

	// View controller to test</p>
	private ListLocales vc = null;
	
	 // Setup the test by simulating support for several locales
	 // that would be configured declaratively in the faces config. 
	 // Then cache a Domains object in context.
	protected void setUp() throws Exception {
		super.setUp();

        // Configure the supported locales for this application
        List list = new ArrayList();
        list.add(new Locale("en"));
        list.add(new Locale("fr"));
        list.add(new Locale("de"));
        list.add(new Locale("es"));
        application.setSupportedLocales(list);

		// simulate a managed bean
		ValueBinding vb = application.createValueBinding("domains");
		vb.setValue(facesContext, new Domains());
		
		vc = new ListLocales();
	
	}

	 //Tear Down the test
	protected void tearDown() throws Exception {
		super.tearDown();
	    vc = null;
	}
	
    // Test behavior of prerender() method
    public void testPrerender() {

        Locale locale = new Locale("en");
        facesContext.getViewRoot().setLocale(locale);
        vc.init();
        vc.prerender();

		SelectItem[] locales = vc.getSupportedLocales();
		assertEquals(locales.length, 4);

		
    }

    // Test behavior of destroy() method
    public void testDestroy() {
        vc.destroy();
		assertEquals(vc.getSupportedLocales(), null);
    }
}
