/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.systest;

import com.gargoylesoftware.htmlunit.html.HtmlAnchor;
import com.gargoylesoftware.htmlunit.html.HtmlForm;
import junit.framework.Test;
import junit.framework.TestSuite;
import org.apache.shale.test.cargo.CargoTestSetup;

/**
 * <p>Simple integration test to validate access to the main menu.</p>
 */
public class UseCasesTestCase extends AbstractTestCase {
    

    // ------------------------------------------------------------ Constructors


    /**
     * <p>Construct a new instance of this test case.</p>
     *
     * @param name Name of the new test case
     */
    public UseCasesTestCase(String name) {

        super(name);

    }


    // ------------------------------------------------------ Instance Variables


    // ------------------------------------------------------ Test Setup Methods


    /**
     * <p>Set up the instance variables required for this test case.</p>
     */
    protected void setUp() throws Exception {

        super.setUp();
        page("/usecases.faces");

    }


    /**
     * <p>Return the set of tests included in this test suite.</p>
     */
    public static Test suite() {

        return new CargoTestSetup(new TestSuite(UseCasesTestCase.class));

    }


    /**
     * <p>Tear down instance variables required by this test case.</p>
     */
    protected void tearDown() throws Exception {

        super.tearDown();

    }



    // ------------------------------------------------- Individual Test Methods


    /**
     * <p>Verify the availability of an appropriate form.</p>
     */
    public void testForm() throws Exception {

        HtmlForm form = (HtmlForm) element("usecasesForm");
        assertNotNull(form);
        assertEquals("", form.getAcceptAttribute());
        assertEquals("", form.getAcceptCharsetAttribute());
        String action = form.getActionAttribute();
        int semicolon = action.indexOf(";jsessionid=");
        if (semicolon >= 0) {
            action = action.substring(0, semicolon);
        }
        assertEquals("/shale-usecases/usecases.faces", action);
        assertEquals("application/x-www-form-urlencoded", form.getEnctypeAttribute());
        assertEquals("", form.getLangAttribute());
        assertEquals("post", form.getMethodAttribute());
        // assertEquals("", form.getNameAttribute()); // Remove test for RI behavior that is not in the spec
        assertEquals("", form.getOnResetAttribute());
        assertEquals("", form.getOnSubmitAttribute());
        assertEquals("", form.getTargetAttribute());

    }


    /**
     * <p>Verify the availability of an appropriate subview hyperlink.</p>
     */
    public void testSubview() throws Exception {

        HtmlAnchor anchor = (HtmlAnchor) element("usecasesForm:subview");
        assertNotNull(anchor);
        assertEquals("", anchor.getAccessKeyAttribute());
        assertEquals("", anchor.getCharsetAttribute());
        assertEquals("", anchor.getCoordsAttribute());
        // assertEquals("#", anchor.getHrefAttribute());
        assertEquals("", anchor.getHrefLangAttribute());
        assertEquals("", anchor.getNameAttribute());
        assertEquals("", anchor.getRelAttribute());
        assertEquals("", anchor.getRevAttribute());
        assertEquals("", anchor.getShapeAttribute());
        assertEquals("", anchor.getTabIndexAttribute());
        assertEquals("", anchor.getTargetAttribute());
        assertEquals("", anchor.getTypeAttribute());
        assertEquals("Subview Processing", anchor.asText());

    }


    /**
     * <p>Verify the title of the returned page.</p>
     */
    public void testTitle() throws Exception {

        assertEquals("Shale Framework Use Cases", title());

    }


}
