/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shale.usecases.systest;

import com.gargoylesoftware.htmlunit.html.HtmlElement;
import com.gargoylesoftware.htmlunit.html.HtmlForm;
import com.gargoylesoftware.htmlunit.html.HtmlSubmitInput;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;

import junit.framework.Test;
import junit.framework.TestSuite;
import org.apache.shale.test.cargo.CargoTestSetup;

/**
 * <p>Test case for view controller lifecycle callbacks testing.</p>
 */
public class ViewControllerTestCase extends AbstractTestCase {


    // ------------------------------------------------------------ Constructors


    // Construct a new instance of this test case.
    public ViewControllerTestCase(String name) {
        super(name);
    }


    // ---------------------------------------------------- Overall Test Methods


    // Set up instance variables required by this test case.
    protected void setUp() throws Exception {

        super.setUp();
        page("/view/test.faces");

    }

    // Return the tests included in this test case.
    public static Test suite() {

        return new CargoTestSetup(new TestSuite(ViewControllerTestCase.class));

    }


    // Tear down instance variables required by this test case.
    protected void tearDown() throws Exception {

        super.tearDown();

    }


    // ------------------------------------------------------------ Test Methods


    /**
     * <p>Validate pristine instance of the test page.</p>
     */
    public void testPristine() throws Exception {

        HtmlForm form = null;
        HtmlElement text = null;
        HtmlSubmitInput submit = null;

        // setUp() should have put us on the page
        assertEquals("View Controller Test", title());
        form = (HtmlForm) element("form");
        assertNotNull(form);
        text = element("form:text");
        assertNotNull(text);
        submit = (HtmlSubmitInput) element("form:submit");
        assertNotNull(submit);

        // Check the expected contents of the "text" element on
        // an initial request for this page.  Note that we cannot
        // check for the destroy event, because it has not yet occurred
        // when the value binding expression in our test page is evaluated
        assertEquals("init/false/prerender/false/", text.asText());

    }


    /**
     * <p>Submit the page and validate the results.</p>
     */
    public void testSubmit() throws Exception {

        // setUp() should have put us on the page
        assertEquals("View Controller Test", title());

        // Submit the form
        HtmlSubmitInput submit = (HtmlSubmitInput) element("form:submit");
        submit(submit);

        // Validate the redispayed content
        assertEquals("View Controller Test", title());
        HtmlElement text = element("form:text");
        assertNotNull(text);
        assertEquals("init/true/preprocess/true/submit/true/prerender/true/", text.asText());

    }


}
